function [t_ice,p_ice,s_ice,h2o_sat,v_ice,m_ice,h2o_ice,ztop,zmax,zbot,iwc,rc] ...
    = pmc_0d_model(z,t,p,h2o,rad)
%  PMC_0d_MODEL a ice growth model that returns various properties of PMCs
%  in thermodynamic equilibrium. 
%
%   The model takes in an atmospheric profile (including droplet size to 
%   take into account the kelvin effect) and returns various properties of
%   the ice, assuming thermodynamic equilibrium. These inlude saturation
%   ratio for each altitude as well as ice mass density peak and layer
%   heights.
%
%
%   The model was provided by Mark Hervig and translated into matlab by Ole
%   Martin Christensen.
%
%
% FORMAT    [t_ice,p_ice,s_ice,h2o_sat,v_ice,m_ice,h2o_ice,ztop,zmax,zbot,iwc,rc] ...
%           = pmc_0d_model(z,t,p,h2o,rad)
%        
% OUT   t_ice  frost point temperature [K]
%       p_ice  saturation vapor pressure over ice [Pa]
%       s_ice  saturation ratio WRT ice [-]
%       h2o_sat  saturation H2O mixing ratio [-]
%       v_ice  ice volume density [m3 / m3]
%       m_ice  ice mass density [kg/m3]
%       h2o_ice  gas phase equivalent H2O in ice [-]
%       ztop  ice layer top altitude [m]
%       zmax  ice layer mass density peak altitude [m]
%       zbot  ice layer bottom altitude [m]
%       iwc  column ice abundance [kg/m2]
%       rc  critical radius [m]
%
% IN    z   altitude [m]
%       t   temperature [K]
%       p   pressure [Pa]
%       h2o   volume mixing ratio [-]
%       rad   ice particle radius [m] 
%
% Reference: A short course in cloud physics (Chapter VI, Formation of cloud
%            droplets); 1996, By: R. R. Rogers and M. M. Yau
%
% 2014-10-10   Created by Ole Martin Christensen.
%

%Define some variables
sfac = 1;
vpop = 'mk';
Mww = 18e-3; %molecular weight of H2O [kg/mol]
rho_ice = 0.93e3; % Ice density [kg/m3]

nz = length(z);
t_ice   = zeros(nz,1) ;
p_ice   = zeros(nz,1) ;
s_ice   = zeros(nz,1) ;
v_ice   = zeros(nz,1) ;
m_ice   = zeros(nz,1) ;
h2o_sat = zeros(nz,1) + 999;
h2o_ice = zeros(nz,1);
kelv     = zeros(nz,1) + 1;   
rc       =  NaN(nz,1);
   
zmax = 0;
ztop = 0;
zbot = 0;
iwc  = 0;


%Start model
for i = 1:length(z)
    if t(i) < 210 && t(i)>0
        %Kelvin effect
        if rad(i)>0
            kelv(i) = kelvin_term(t(i),rad(i));
        else
            kelv(i) = 1;
        end
        %H2O saturation pressure 
        if strcmp(vpop,'mk')
            p_ice(i) = kelv(i) * e_eq_ice_mk(t(i)); %use murphy and koop model [Pa];
        end
        
        h2o_sat(i) = p_ice(i) / p(i); %saturation mixing ratio [-]
        s_ice(i) = h2o(i) / h2o_sat(i); %saturation ratio [-]
        
        %Critical radius
        if s_ice(i) == 1
            rc(i) = inf;
        elseif s_ice(i)>1
            rc(i) = critical_radius_ice(t(i),s_ice(i)); %[m]
        end
        
        %Equilibrium ice properties
        
        q_xs = h2o(i) - h2o_sat(i); %excess h2o mix ratio [-]
        
        q_xs = q_xs * sfac; % scale it by sfac (Some empirical factor?)
        
        if q_xs > 0 %if saturated then
            n_xs = p(i)*q_xs/(constants('GAS_CONST')*t(i)); % excess h2o [mol/m3]
            
            v_ice(i) = n_xs * Mww / rho_ice;  %ice volume density, m3 / m3
            m_ice(i) = n_xs * Mww; % ice mass density, kg/m3
            h2o_ice(i) = q_xs; %H2O(ice), mixing ratio
        end
        
%       Find the frost point temperature, t_ice.  Use the fact that
%       a linear relationship exists between 1/T and log10(p_h2o).
%       Do a linear interpolation between some hi and low temp.
        
        p_h2o = p(i) * h2o(i); %h2o partial pressure [Pa]
        
        t1 = t(i) - 20;
        t2 = t(i) + 20;
        
        if strcmp(vpop,'mk')
            p1 = kelv(i) * e_eq_ice_mk(t1); %use murphy and koop model;
            p2 = kelv(i) * e_eq_ice_mk(t2); %use murphy and koop model;
        end
        
        dsds = (log10(p2) - log10(p_h2o))/(log10(p2) - log10(p1)); %linear interpolate
        t_ice(i) = 1 / ( 1/t2 - dsds * (1/t2 - 1/t1) ); %frost point temperature [K]
    end
end

k = find(z > z(1) & z < z(end) & m_ice > 0); %find areas with ice

if ~isempty(k) %if ice exists
    
    %find altitude of maximum mass
    [~,l] = max(m_ice(k)); 
    zmax = z(k(l));  %
    
    %find top and bottom part of ice layer
    ztop = max(z(k)); %
    zbot = min(z(k)); %
    
    %integrate over the ice layer to find total IWC [kg/m2]
    for i = 1:length(k)
        if z(k(i)) > zmax-2
            dz = abs(z(k(i)+1)-z(k(i)-1))*0.5; %layer spacing [m]
            iwc = iwc + m_ice(k(i)) * dz;       % IWC [kg/m2] 
        end
    end
end
